import { IComputedValue, IObservableValue } from "mobx";
import { exportState, TableDataColumn, TableDataRow, TableRowId } from "./index";
export type CreatedTableState<DataItem = any> = ReturnType<typeof createTableState<DataItem>>;
export type StorableCreateTableState<DataItem = any> = ReturnType<typeof exportState<DataItem>>;
export interface ResourceWithId {
    id?: TableRowId;
    getId?(): TableRowId;
}
export interface CreateTableStateParams<ResourceItem extends ResourceWithId = {}> {
    tableId: string;
    items: ResourceItem[];
    /**
     * Columns definition as `Table.props.columns`.
     * Used to build `Table.props.rows` state.
     */
    columns: TableDataColumn<ResourceItem>[];
    /**
     * Allows to customize row before processing by table (e.g. make `selectable`)
     */
    customizeRows?: (row: TableDataRow<ResourceItem>) => Partial<TableDataRow<ResourceItem>>;
    customSearchResults?: (searchText: string, rows: TableDataRow<ResourceItem>[]) => TableDataRow<ResourceItem>[];
    /**
     * Provide uniq ID for data items
     */
    getRowId?: (dataItem: ResourceItem & ResourceWithId) => TableRowId;
    /**
     * Handle filtering results with search field
     * mobx.computed() or mobx.observable.box() that participates in filtered rows state.
     */
    searchBox?: IComputedValue<string> | IObservableValue<string>;
}
export declare function createTableState<DataItem extends ResourceWithId = {}>(params: CreateTableStateParams<DataItem>): {
    tableId: string;
    searchText: IComputedValue<string>;
    columnSizes: import("mobx").ObservableMap<string, string>;
    columnsOrder: import("mobx").IObservableArray<string>;
    hiddenColumns: import("mobx").ObservableSet<string>;
    sortedColumns: import("mobx").ObservableMap<string, "asc" | "desc">;
    headingColumns: TableDataColumn<DataItem>[];
    headingColumnsReordered: IComputedValue<TableDataColumn<DataItem>[]>;
    tableRowIds: IComputedValue<TableRowId[]>;
    tableRowsMap: IComputedValue<Map<TableRowId, TableDataRow<DataItem>>>;
    sortedTableRows: IComputedValue<TableDataRow<DataItem>[]>;
    searchResultTableRows: IComputedValue<TableDataRow<DataItem>[]>;
    searchResultTableRowIds: IComputedValue<TableRowId[]>;
    selectedRowsId: import("mobx").ObservableSet<TableRowId>;
    selectedTableRowsAll: IComputedValue<TableDataRow<DataItem>[]>;
    selectedTableRowsFiltered: IComputedValue<TableDataRow<DataItem>[]>;
    isSelectedAll: IComputedValue<boolean>;
    toggleRowSelection: (rowId: TableRowId, force?: boolean) => void;
    toggleRowSelectionAll: (force?: boolean) => void;
};
