import React from "react";
import { TableDataRow } from "./table-row";
import type { TableDataColumn } from "./table-column";
export interface TableProps<DataItem = any> {
    id?: string;
    className?: string;
    classes?: TableClassNames;
    style?: React.CSSProperties;
    /**
     * Use or not rows virtualization to render table grid.
     * When `true` table element must have some defined height.
     * @default true
     */
    virtual?: boolean;
    /**
     * Table's header html block.
     * Scrolled with table items behind heading columns.
     */
    header?: React.ReactNode;
    /**
     * Heading columns definition within the grid (aka <thead>-s but in data-terms).
     * This field produce floating html block that stays always on the top (sticky) of parent scrollable list.
     */
    columns: TableDataColumn<DataItem>[];
    /**
     * Data rows with required columns.
     * All the columns inside extended from "heading" `props.columns` and has all the `data-getters`
     * and callbacks required for specific columns to handle the data item (e.g. sort, display, etc)
     * Usually `props.rows` needs to be generated with some items list and used above `props.columns`
     */
    rows: TableDataRow<DataItem>[];
    /**
     * Min-size (width) for all columns by default, could be changed/resized from UI
     * @default 100
     */
    minSizeAllColumns?: number;
    /**
     * Default fixed row size (height) for "grid-auto-rows"
     * @default 50
     */
    rowSize?: number;
    /**
     * Allows to add custom static rows or some other contents (e.g. "+" button with `position: absolute`)
     */
    children?: React.ReactNode;
}
export interface TableClassNames {
    headerClass?: string;
    theadClass?: string;
    theadTitleClass?: string;
    rowBaseClass?: string;
    columnBaseClass?: string;
    resizableColumn?: string;
    sortableColumn?: string;
    draggableColumn?: string;
    draggableColumnActive?: string;
    draggableIcon?: string;
    droppableColumn?: string;
    droppableColumnActive?: string;
    selectableRow?: string;
    selectedRow?: string;
    sortingArrow?: string;
    sortingArrowAsc?: string;
    sortingArrowDesc?: string;
}
export declare const Table: (props: TableProps) => JSX.Element;
export declare function makeCssGridTemplate(columns: TableDataColumn[]): string;
